==> haskell-text-builder-0.6.7-118-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-BwDH1X984Rs70mCeFGuiM6
key:                  text-builder-0.6.7-BwDH1X984Rs70mCeFGuiM6
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  5c0c0a02d5735ca8875bcb89cf09c60d
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-BwDH1X984Rs70mCeFGuiM6
depends:
    base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
    text-builder-dev-0.3.3.2-HMzBhQ2X6WIUoQpfgbsP4

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.7-129-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-bWO1uP3xY5GNnPsBNUejA
key:                  text-builder-0.6.7-bWO1uP3xY5GNnPsBNUejA
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  ee1ad3d5ca4a25e87f65a64b489b8e8f
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-bWO1uP3xY5GNnPsBNUejA
depends:
    base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
    text-builder-dev-0.3.3.2-5zvuKe53WEn1N6fJdRBPWQ

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
